@@ -20,7 +20,7 @@
 #  respective owners and no grant or license is provided thereof.
 
 package PDL::Opt::Simplex::Simple;
-$VERSION = '1.6';
+$VERSION = '1.7';
 
 use 5.010;
 use strict;
@@ -337,8 +337,7 @@ sub _simplex_log
 
 	my @log_vars = $self->_get_simplex_vars($vec);
 	$self->{log}->($log_vars[0], {
-		ssize =>
-			ref($ssize) eq 'PDL' ? $ssize->sclr : $ssize,
+		ssize => $ssize->sclr,
 		minima => $minima,
 		elapsed => $elapsed,
 		srand => $self->{srand},
@@ -346,8 +345,7 @@ sub _simplex_log
 
 		num_passes => scalar( @{ $self->{_ssize} }),
 		best_pass => $self->{best_pass},
-		best_minima =>
-			ref($self->{best_minima}) eq 'PDL' ? $self->{best_minima}->sclr : $self->{best_minima},
+		best_minima => $self->{best_minima}->sclr,
 		best_vars => $self->{best_vars},
 		log_count => $self->{log_count},
 		cancel => $self->{cancel},
